
-- FTS System Test Queries

use SQLServerArticles
go

select * from sys.dm_fts_index_keywords(DB_ID('SQLServerArticles'), OBJECT_ID('Documents'))
order by document_count desc
-- reconfigure, record, data, SQL, server, microsoft, worker

select * from Documents --(stream_id = UKEY, name = column, file_stream = column, file_type=type)

select count(*) from Documents

----- CONTAINS ------

-- single term, all columns
select name from Documents
where CONTAINS(*, 'data')

-- todo: search by multiple columns

-- ORs
select name from Documents
where CONTAINS(*, '"data" OR "SQL" OR "record"')

-- todo: more compounds

-- term prefix
select name from Documents
where CONTAINS(*, 'record*')

-- inflectional search
select name from Documents
where CONTAINS(*, 'FORMSOF(INFLECTIONAL, "record")')

-- thesaurus search
SELECT name from Documents
WHERE CONTAINS(*, 'FORMSOF(THESAURUS, record)')

-- property search, single term
select name from Documents
WHERE CONTAINS(PROPERTY(file_stream, 'Title'), 'data')

-- property search, multiple terms
select name from Documents
WHERE CONTAINS(PROPERTY(file_stream, 'Title'), 'data OR SQL')

-- NEAR, order senstive
SELECT name FROM Documents
WHERE CONTAINS(file_stream, 'NEAR(("data", "SQL"), 5, TRUE)');

-- NEAR, not order senstive
SELECT name FROM Documents
WHERE CONTAINS(file_stream, 'NEAR(("data", "SQL"), 5, FALSE)');

-- old-style NEAR
SELECT name FROM Documents
WHERE CONTAINS(*, 'data NEAR SQL')

-- old-style NEAR, multiple NEARs
SELECT name FROM Documents
WHERE CONTAINS(*, 'data NEAR SQL NEAR backup')

-- weighted search with ISABOUT, 3 terms
SELECT name FROM Documents
WHERE CONTAINS(*, 'ISABOUT (performance weight (.8), data weight (.4), record weight (.2) )' );

-- weighted search with ISABOUT, 5 terms
SELECT name FROM Documents
WHERE CONTAINS(*, 'ISABOUT (performance weight (.8), data weight (.4), record weight (.2), backup weight (.3), SQL weight (.1)  )' );

-- language specification
SELECT name FROM Documents
WHERE CONTAINS(*, 'data OR SQL', LANGUAGE 1043)

------ CONTAINSTABLE ------

-- single term, all columns
select * from CONTAINSTABLE(documents, *, 'data')

-- single term, top 10 by rank
select * from CONTAINSTABLE(documents, *, 'data', 10)

-- weighted
select * from CONTAINSTABLE(documents, *, 'ISABOUT (performance weight (.8), data weight (.4), record weight (.2) )' );

-- Plan: FTS-1
-- weighted, top 5
select * from CONTAINSTABLE(documents, *, 'ISABOUT (performance weight (.8), data weight (.4), record weight (.2) )',5);

------ FREETEXT -------

-- 3 terms
select name from documents
where FREETEXT(*, 'SQL data record')

-- 5 terms
select name from documents
where FREETEXT(*, 'SQL data record performance microsoft')

-- rank of zero in FREETEXTTABLE
select name from documents
where FREETEXT(*, 'data backup')

-- parameterized
/*
create procedure get_documents (@searchstring NVARCHAR(128))
as
select name from documents
where FREETEXT(*, @searchstring)
*/

-- 111 rows
EXEC get_documents N'SQL data record';

-- 21 rows
EXEC get_documents N'foo bar';

------ FREETEXTTABLE -------

-- looks like these terms have to occur together to get a rank
select * from FREETEXTTABLE(documents, *, 'Microsoft SQL Server')

select * from FREETEXTTABLE(documents, *, 'Microsoft SQL Server', 10)

-- all have rank of zero
select * from FREETEXTTABLE(documents, *, 'data backup')
select * from FREETEXTTABLE(documents, *, 'backup data')

-- one term works fine, lots of non-zero high rankings
select * from FREETEXTTABLE(documents, *, 'data')
-- one term works fine, lots of non-zero high rankings
select * from FREETEXTTABLE(documents, *, 'backup')
-- all have rank of zero
select * from FREETEXTTABLE(documents, *, 'data backup')
select * from FREETEXTTABLE(documents, *, 'backup data')

ALTER FULLTEXT CATALOG ft REBUILD

SELECT FULLTEXTCATALOGPROPERTY ('ft','MergeStatus')

select objectpropertyex(object_id('Documents'),'TableFulltextPopulateStatus')
select objectpropertyex(object_id('Documents'),'TableFullTextSemanticExtraction')



