
create database GaelicLyrics
on primary 
  (name = GaelicLyrics_file, filename = N'C:\Files\GaelicLyrics\GaelicLyrics_File.mdf' ),
filegroup FSStorage contains filestream 
  ( name = GaelicLyrics_fs_file, filename = N'C:\Files\GaelicLyrics\GaelicLyrics_FS' )
with filestream ( 
    non_transacted_access = full,
    directory_name = N'GaelicLyrics' )

use GaelicLyrics
go

-- create a filetable
create table Songs as filetable
with (filetable_directory = N'Songs')
go

-- search a search property list
CREATE SEARCH PROPERTY LIST DocumentProperties;
GO
ALTER SEARCH PROPERTY LIST DocumentProperties
   ADD 'Title'
   WITH ( PROPERTY_SET_GUID = 'F29F85E0-4FF9-1068-AB91-08002B27B3D9', PROPERTY_INT_ID = 2, 
      PROPERTY_DESCRIPTION = 'System.Title - Title of the item.' );
GO
ALTER SEARCH PROPERTY LIST DocumentProperties
    ADD 'Author'
   WITH ( PROPERTY_SET_GUID = 'F29F85E0-4FF9-1068-AB91-08002B27B3D9', PROPERTY_INT_ID = 4, 
      PROPERTY_DESCRIPTION = 'System.Author - Author or authors of the item.' );
GO
ALTER SEARCH PROPERTY LIST DocumentProperties 
    ADD 'Tags'
   WITH ( PROPERTY_SET_GUID = 'F29F85E0-4FF9-1068-AB91-08002B27B3D9', PROPERTY_INT_ID = 5, 
      PROPERTY_DESCRIPTION = 'System.Keywords - Keywords (Tags) of the item.' );
GO

-- 
SELECT * FROM sys.registered_search_properties;
SELECT * FROM sys.registered_search_property_lists;

SELECT name, prop.*
FROM sys.registered_search_properties prop
JOIN sys.registered_search_property_lists list
ON prop.property_list_id = list.property_list_id

-- create FTS catalog
CREATE FULLTEXT CATALOG ft AS DEFAULT -- WITH ACCENT_SENSITIVITY ON
GO

-- FTS index needs a unique index, add it
CREATE UNIQUE INDEX SongsFt ON GaelicLyrics..Songs(stream_id)
GO

-- Create FTS index
-- But no support for LCID 2108 (gd-ie) or LCID 1084 (gd) either, for that matter
CREATE FULLTEXT INDEX ON GaelicLyrics..Songs
	(file_stream TYPE COLUMN file_type LANGUAGE 0)
	KEY INDEX SongsFt ON ft
	WITH SEARCH PROPERTY LIST = DocumentProperties
GO

-- check population status
SELECT fulltextcatalogproperty('ft', 'populatestatus')
GO

-- Traditional FTS
SELECT name DocumentName, file_stream.GetFileNamespacePath() Path FROM Songs
	WHERE CONTAINS(file_stream, 'cailn');

-- More traditional FTS
SELECT name DocumentName, file_stream.GetFileNamespacePath() Path FROM Songs
	WHERE CONTAINS(file_stream, 'deas');

SELECT name DocumentName, file_stream.GetFileNamespacePath() Path FROM Songs
	WHERE CONTAINS(file_stream, 'g');

SELECT name DocumentName, file_stream.GetFileNamespacePath() Path FROM Songs
	WHERE CONTAINS(file_stream, 'cailn OR deas');

SELECT name DocumentName, file_stream.GetFileNamespacePath() Path FROM Songs
	WHERE CONTAINS(file_stream, 'cailn AND deas');

SELECT name DocumentName, file_stream.GetFileNamespacePath() Path FROM Songs
	WHERE CONTAINS(file_stream, 'cailn AND (deas OR g)');

-- Mix FTS and File Location-base search
SELECT name DocumentName, file_stream.GetFileNamespacePath() Path FROM Songs
	WHERE CONTAINS(file_stream, 'cailn AND (deas OR g)')
	AND file_stream.GetFileNamespacePath() LIKE '%IrishGaelic%';

-- New NEAR operator
SELECT name DocumentName, file_stream.GetFileNamespacePath() Path FROM Songs
	WHERE CONTAINS(file_stream, 'NEAR(("cailn", "deas"), 5, FALSE)');

-- New NEAR operator
SELECT name DocumentName, file_stream.GetFileNamespacePath() Path FROM Songs
	WHERE CONTAINS(file_stream, 'NEAR(("cailn", "deas"), 5, TRUE)');

-- Property-based search
SELECT name DocumentName, file_stream.GetFileNamespacePath() Path FROM Songs
	WHERE CONTAINS(PROPERTY(file_stream, 'Author'), 'Traditional');
GO

-- Property-based search
SELECT name DocumentName, file_stream.GetFileNamespacePath() Path FROM Songs
	WHERE CONTAINS(PROPERTY(file_stream, 'Title'), 'Cailn AND tSlibhe AND Ruaidh');
GO

-- Let's go search for words to look for
SELECT * FROM sys.dm_fts_index_keywords(DB_ID('GaelicLyrics'),OBJECT_ID('dbo.Songs'))
order by document_count desc;

SELECT * FROM sys.dm_fts_index_keywords_by_document(DB_ID('GaelicLyrics'),OBJECT_ID('dbo.Songs'))

SELECT * FROM sys.dm_fts_index_keywords_by_property(DB_ID('GaelicLyrics'),OBJECT_ID('dbo.Songs'))

select * from 

-- Looks like we need a stopword list...

CREATE FULLTEXT STOPLIST GaelicStoplist;
GO

-- Add these one at a time (this just scratches the surface
ALTER FULLTEXT STOPLIST GaelicStoplist ADD 'na' LANGUAGE 0;
ALTER FULLTEXT STOPLIST GaelicStoplist ADD 'ach' LANGUAGE 0;
ALTER FULLTEXT STOPLIST GaelicStoplist ADD 'mo' LANGUAGE 0;
ALTER FULLTEXT STOPLIST GaelicStoplist ADD 'le' LANGUAGE 0;

ALTER FULLTEXT INDEX ON GaelicLyrics..Songs
SET STOPLIST = GaelicStoplist;

-- Have to repopulate the index
ALTER FULLTEXT INDEX ON GaelicLyrics..Songs
START FULL POPULATION;

-- Internals 
SELECT * FROM sys.internal_tables;


-- drop database when done
drop database GaelicLyrics