
-- load new IFilters
exec sp_fulltext_service 'load_os_resources', 1

-- check that it contains the suffixes you're using
select document_type, path from sys.fulltext_document_types

create database test
go

use test
go

create table dbo.docs (
 id int identity not null,
 doctype varchar(20),
 doc varbinary(max), 
   constraint pk_id primary key (id)
)
go 

-- from BOL
-- in general, find Windows Search Properties here: http://msdn.microsoft.com/en-us/library/dd561977(v=VS.85).aspx
-- or here (re:BOL) http://msdn.microsoft.com/en-us/library/dd368864(VS.85).aspx#generic
CREATE SEARCH PROPERTY LIST DocumentProperties;
GO
ALTER SEARCH PROPERTY LIST DocumentProperties
   ADD 'Title' 
   WITH ( PROPERTY_SET_GUID = 'F29F85E0-4FF9-1068-AB91-08002B27B3D9', PROPERTY_INT_ID = 2, 
      PROPERTY_DESCRIPTION = 'System.Title - Title of the item.' );
ALTER SEARCH PROPERTY LIST DocumentProperties
    ADD 'Author'
   WITH ( PROPERTY_SET_GUID = 'F29F85E0-4FF9-1068-AB91-08002B27B3D9', PROPERTY_INT_ID = 4, 
      PROPERTY_DESCRIPTION = 'System.Author - Author or authors of the item.' );
ALTER SEARCH PROPERTY LIST DocumentProperties 
    ADD 'Tags'
   WITH ( PROPERTY_SET_GUID = 'F29F85E0-4FF9-1068-AB91-08002B27B3D9', PROPERTY_INT_ID = 5, 
      PROPERTY_DESCRIPTION = 'System.Keywords - Keywords (Tags) of the item.' );
GO

CREATE FULLTEXT CATALOG FTCatalog AS DEFAULT;
GO

CREATE FULLTEXT INDEX ON docs(
Doc TYPE COLUMN doctype LANGUAGE English
)
KEY INDEX pk_id ON (FTCatalog)
WITH (search property list = DocumentProperties)
go

ALTER FULLTEXT INDEX ON docs
   START FULL POPULATION;
GO

-- until status = 0 (populated, idle)
select objectpropertyex(object_id('docs'),'TableFulltextPopulateStatus')
go

-- Office 2010 document, Author = Bob Beauchemin, Title = Sample Document
declare @x varbinary(max)
SET @x = ( 
 SELECT * FROM OPENROWSET
  (BULK 'c:\temp\SampleDoc.docx', SINGLE_BLOB) as X)

insert into dbo.docs values('.docx',@x)
go

-- search property list and related metadata
select * from sys.registered_search_properties 
select * from sys.registered_search_property_lists
select * from sys.dm_fts_index_keywords_by_property(
 DB_ID('test'), 
 OBJECT_ID('docs'))

-- search by property
SELECT * FROM docs WHERE CONTAINS(PROPERTY(doc,'Title'), 'Sample');
GO

SELECT * FROM docs WHERE CONTAINS(PROPERTY(doc,'Author'), 'Bob');
GO

-- this (search content + properties) works too
SELECT * FROM docs WHERE CONTAINS(doc, 'Bob');
GO

DROP DATABASE test
GO

